@@ -19,7 +19,7 @@ import enum
 import functools
 from typing import Text
 
-from tensorflow.lite.python.metrics import converter_error_data_pb2
+from tensorflow.compiler.mlir.lite.metrics import converter_error_data_pb2
 from tensorflow.lite.python.metrics import metrics
 
 
@@ -39,7 +39,7 @@ SubComponentItem = collections.namedtuple("SubComponentItem",
                                           ["name", "component"])
 
 
-class SubComponent(enum.Enum):
+class SubComponent(SubComponentItem, enum.Enum):
   """Enum class defining name of the converter subcomponents.
 
   This enum only defines the subcomponents in Python, there might be more
